@@ -1,16 +1,10 @@
-( cd opt/kde/share/doc/HTML/en/kmouth ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kmouth ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmag ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmag ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmousetool ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmousetool ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kttsd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kttsd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/lib ; rm -rf libkttsd.so.4 )
-( cd opt/kde/lib ; ln -sf libkttsd.so.4.3.0 libkttsd.so.4 )
-( cd opt/kde/lib ; rm -rf libkttsd.so )
-( cd opt/kde/lib ; ln -sf libkttsd.so.4 libkttsd.so )
-#%% begin initialize kdeaccessibility-4.3.5
+( cd opt/kde/share/doc/HTML/en/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kmouth ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+#%% begin initialize kdeaccessibility-4.4.5
 if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
 	/bin/bash /opt/kde/bin/plamo_update_kde.sh
 fi
